import { service } from '../utils/request';
const api1 = "/mosty-jcgl"
// 人员列表
export function getdataCyry(params) {
    return service({
        url: api1 + `/tbJcglXfCyry`,
        method: 'GET',
        params
    })
}


// 删除人员
export function deletedataCyry(data) {
    return service({
        url: api1 + `/tbJcglXfCyry/bacth`,
        method: 'POST',
        data
    })
}

// 人员详情
export function cyryDetail(params) {
    return service({
        url: api1 + `/tbJcglXfCyry/`+params,
        method: 'GET',
    })
}


// 编辑
export function editDetail(data) {
    return service({
        url: api1 + `/tbJcglXfCyry`,
        method: 'PUT',
        data
    })
}

// 新增
export function addDetail(data) {
    return service({
        url: api1 + `/tbJcglXfCyry`,
        method: 'POST',
        data
    })
}


// 单位管理
export function getdataDwgl(params) {
    return service({
        url: api1 + `/tbJcglXfDwgl`,
        method: 'GET',
        params
    })
}

// 新增单位管理
export function addDwgl(data) {
    return service({
        url: api1 + `/tbJcglXfDwgl`,
        method: 'POST',
        data
    })
}
// 新增单位管理
export function editDwgl(data) {
    return service({
        url: api1 + `/tbJcglXfDwgl`,
        method: 'PUT',
        data
    })
}
// 单位管理详情
export function dwglDetail(params) {
    return service({
        url: api1 + `/tbJcglXfDwgl/`+params,
        method: 'GET',
    })
}


// 删除单位
export function deletedataDw(data) {
    return service({
        url: api1 + `/tbJcglXfDwgl/bacth`,
        method: 'POST',
        data
    })
}


// 任务列表
export function getdataRw(params) {
    return service({
        url: api1 + `/tbJcglXf`,
        method: 'GET',
        params
    })
}

// 删除任务
export function deletedataRw(data) {
    return service({
        url: api1 + `/tbJcglXf/bacth`,
        method: 'POST',
        data
    })
}
// 删除任务
export function plsbData(data) {
    return service({
        url: api1 + `/tbJcglXf/bacthSb`,
        method: 'POST',
        data
    })
}

// 详情任务
export function rwDetail(params) {
    return service({
        url: api1 + `/tbJcglXf/`+ params,
        method: 'GET',
    })
}
// 新增任务
export function addRw(data) {
    return service({
        url: api1 + `/tbJcglXf/`,
        method: 'POST',
        data
    })
}
// 编辑任务
export function eidtRw(data) {
    return service({
        url: api1 + `/tbJcglXf/`,
        method: 'PUT',
        data
    })
}

// 战果列表
export function getdataZg(params) {
    return service({
        url: api1 + `/tbJcglXfZg`,
        method: 'GET',
        params
    })
}
// 新增战果
export function addDataZg(data) {
    return service({
        url: api1 + `/tbJcglXfZg`,
        method: 'POST',
        data
    })
}
// 编辑战果
export function editDataZg(data) {
    return service({
        url: api1 + `/tbJcglXfZg`,
        method: 'PUT',
        data
    })
}
// 战国详情
export function zgDetail(params) {
    return service({
        url: api1 + `/tbJcglXfZg/`+params,
        method: 'GET',
    })
}

// 删除站国
export function deletedataZg(data) {
    return service({
        url: api1 + `/tbJcglXfZg/`+data,
        method: 'DELETE',
    })
}

